==> haskell-aeson-compat-0.3.9-156-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-compat
version:              0.3.9
visibility:           public
id:                   aeson-compat-0.3.9-6dpz7cTtNeS7Edm2y6lTZe
key:                  aeson-compat-0.3.9-6dpz7cTtNeS7Edm2y6lTZe
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/aeson-compat#readme
synopsis:             Compatibility layer for aeson
description:          Compatibility layer for @aeson@
category:             Web
abi:                  71e981ef07111cab0b99b72229331263
exposed:              True
exposed-modules:      Data.Aeson.Compat
import-dirs:          /usr/lib/ghc-8.10.3/site-local/aeson-compat-0.3.9
library-dirs:         /usr/lib/ghc-8.10.3/site-local/aeson-compat-0.3.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/aeson-compat-0.3.9
hs-libraries:         HSaeson-compat-0.3.9-6dpz7cTtNeS7Edm2y6lTZe
depends:
    aeson-1.5.4.1-2CAWo3gcbCSCjWuZ8mOFKc
    attoparsec-0.13.2.4-4yia8KW5L0uBv6MqL2Fffi
    attoparsec-iso8601-1.0.1.0-8KUcJoVLESOKLC1MUl140V base-4.14.1.0
    base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3 bytestring-0.10.12.0
    containers-0.6.2.1 exceptions-0.10.4
    hashable-1.3.0.0-AuOWFkmW3BKQo2eaHHrrX
    scientific-0.3.6.2-EVtj3KqB9jpCpW3irSEx3j
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe text-1.2.4.1 time-1.9.3
    time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
    unordered-containers-0.2.13.0-GkweYkpoMGZ8mML63K9Z6H
    vector-0.12.1.2-13ERBhpJHs04DSBWSaT2Mz

haddock-interfaces:
    /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock

haddock-html:         /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-compat-0.3.9-161-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-compat
version:              0.3.9
visibility:           public
id:                   aeson-compat-0.3.9-94EmTQcYPWQ6pZGB8mqAyD
key:                  aeson-compat-0.3.9-94EmTQcYPWQ6pZGB8mqAyD
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/aeson-compat#readme
synopsis:             Compatibility layer for aeson
description:          Compatibility layer for @aeson@
category:             Web
abi:                  e2af7d94d97d899b6dcd896bf904384a
exposed:              True
exposed-modules:      Data.Aeson.Compat
import-dirs:          /usr/lib/ghc-8.10.3/site-local/aeson-compat-0.3.9
library-dirs:         /usr/lib/ghc-8.10.3/site-local/aeson-compat-0.3.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/aeson-compat-0.3.9
hs-libraries:         HSaeson-compat-0.3.9-94EmTQcYPWQ6pZGB8mqAyD
depends:
    aeson-1.5.4.1-KEDpjWRN4PnwanaxkUvMN
    attoparsec-0.13.2.4-2xssqE3sbQuJGvEDlr5HPN
    attoparsec-iso8601-1.0.1.0-36nsSNzTVPCKVKga3urD8t base-4.14.1.0
    base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3 bytestring-0.10.12.0
    containers-0.6.2.1 exceptions-0.10.4
    hashable-1.3.0.0-2hTNCY6h24LBZEHqacy9BZ
    scientific-0.3.6.2-4T9tdREaNXCARYmknnW6vk
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C text-1.2.4.1 time-1.9.3
    time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
    unordered-containers-0.2.13.0-602GQuCMlfP9kZrcq9TZvH
    vector-0.12.1.2-5hszrBfumemIu85xm28LVC

haddock-interfaces:
    /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock

haddock-html:         /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
